==> 6.2.0.056.zip: extsearch/src/Application/translations/en/d3_extsearch_lang.php <==
<?php

/**
 * This Software is the property of Data Development and is protected
 * by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * http://www.shopmodule.com
 *
 * @copyright (C) D3 Data Development (Inh. Thomas Dartsch)
 * @author    D3 Data Development - Daniel Seifert <support@shopmodule.com>
 * @link      http://www.oxidmodule.com
 */

$sLangName = "English";

// -------------------------------
// RESOURCE IDENTITFIER = STRING
// -------------------------------
$aLang = array(

//Navigation
    'charset'                                => 'UTF-8',

    'D3_EXTSEARCH_FIELD_NOTICE'              => 'search item',

    'D3_EXTSEARCH_QUICK_HITS'                => 'Hits for',
    'D3_EXTSEARCH_QUICK_SIMILARHITS'         => 'similar hits for',
    'D3_EXTSEARCH_QUICK_MULTIPLEHITS'        => 'suggestions',
    'D3_EXTSEARCH_QUICK_TOBASKET'            => 'add to shopping cart',
    'D3_EXTSEARCH_QUICK_SEARCH'              => 'Searching...',
    'D3_EXTSEARCH_QUICK_NOHIT'               => 'No articles found.',
    'D3_EXTSEARCH_QUICK_TOMUCHHITS'          => 'There are to much hits for this view. <br>Please click here for list view.',
    'D3_EXTSEARCH_QUICK_STARTSEARCH'         => 'start further search...',
    'D3_EXTSEARCH_QUICK_ARTICLE'             => 'article',
    'D3_EXTSEARCH_QUICK_CATEGORY'            => 'category',
    'D3_EXTSEARCH_QUICK_MANUFACTURER'        => 'brand',
    'D3_EXTSEARCH_QUICK_VENDOR'              => 'vendor',
    'D3_EXTSEARCH_QUICK_CONTENT'             => 'information',
    'D3_EXTSEARCH_QUICK_CLOSE'               => 'window close',

    'D3_EXTSEARCH_EXT_NOARTMSG'              => 'To this term were only found a few articles.  We show you similar articles. ',
    'D3_EXTSEARCH_EXT_LESSARTMSG'            => 'To this term were only found a few articles. We added some similar articles to the list.',
    'D3_EXTSEARCH_EXT_PLUGINHEADLINE'        => 'search faster, find faster',
    'D3_EXTSEARCH_EXT_PLUGINBROWSERERROR'    => 'This search extension works in Mozilla Firefox from version 2.0 on and Microsoft Internet Explorer from version 7 on.',
    'D3_EXTSEARCH_EXT_PLUGININSTALLMSG'      => 'Install our free advanced search. You will add our shop into the search function of your browser (top right). So you will always find everything to your convenience.<br>(available for Mozilla Firefox from Version 2 on and Microsoft Internet Explorer from Version 7 on)',
    'D3_EXTSEARCH_EXT_PLUGININSTALLBTN'      => 'install plugin for advanced search',

    'D3_EXTSEARCH_EXT_SEARCHBOX'             => 'filters',
    'D3_EXTSEARCH_EXT_CHOOSECAT'             => 'choose a category',
    'D3_EXTSEARCH_EXT_HITSINCAT'             => 'hits in',
    'D3_EXTSEARCH_EXT_THISCAT'               => 'these categories:',
    'D3_EXTSEARCH_EXT_ALLCATHITS'            => 'show hits for all categories',
    'D3_EXTSEARCH_EXT_CATEGORIES'            => 'Categories:',
    'D3_EXTSEARCH_EXT_SEARCHINCATEGORIES'    => 'search in all categories',
    'D3_EXTSEARCH_EXT_HITSINVENDOR'          => 'hits for',
    'D3_EXTSEARCH_EXT_THISVENDORS'           => 'associated vendors:',
    'D3_EXTSEARCH_EXT_VENDORS'               => 'Vendors:',
    'D3_EXTSEARCH_EXT_SEARCHINVENDORS'       => 'search in all vendors',
    'D3_EXTSEARCH_EXT_ALLVENDORHITS'         => 'show all vendor hits',
    'D3_EXTSEARCH_EXT_CHOOSEVENDOR'          => 'choose a vendor',
    'D3_EXTSEARCH_EXT_HITSINMANUFACTURER'    => 'hits for',
    'D3_EXTSEARCH_EXT_THISMANUFACTURERS'     => 'associated brand:',
    'D3_EXTSEARCH_EXT_MANUFACTURERS'         => 'Brand:',
    'D3_EXTSEARCH_EXT_SEARCHINMANUFACTURERS' => 'search in all brands',
    'D3_EXTSEARCH_EXT_ALLMANUFACTURERHITS'   => 'show all brand hits',
    'D3_EXTSEARCH_EXT_CHOOSEMANUFACTURER'    => 'choose a brand',
    'D3_EXTSEARCH_EXT_HITSATTRIBS'           => 'associated specifications',
    'D3_EXTSEARCH_EXT_ATTRIBSNOSELECTION1'   => 'choose',
    'D3_EXTSEARCH_EXT_ATTRIBSNOSELECTION2'   => '',
    'D3_EXTSEARCH_EXT_ATTRIBSDESELECT1'      => 'deselect',
    'D3_EXTSEARCH_EXT_ATTRIBSDESELECT2'      => '',
    'D3_EXTSEARCH_EXT_ATTRIB_NOASSIGN'       => 'not to "%s" assigned articles',
    'D3_EXTSEARCH_EXT_MULTIPLESELECT'        => 'select multiple "%s"',
    'D3_EXTSEARCH_EXT_ASSIGNFILTER'          => 'assign filter',
    'D3_EXTSEARCH_EXT_UNASSIGNFILTER'        => 'deselect',
    'D3_EXTSEARCH_EXT_CLEARFILTER'           => 'clear all filters',
    'D3_EXTSEARCH_EXT_START_SEARCH'          => 'start search',
    'D3_EXTSEARCH_EXT_ALL'                   => 'all',
    'D3_EXTSEARCH_EXT_CHOOSEPRICE'           => 'choose a price range',
    'D3_EXTSEARCH_EXT_DESELECTPRICE'         => 'show all price ranges',
    'D3_EXTSEARCH_EXT_PRICECATS'             => 'price range',
    'D3_EXTSEARCH_EXT_PRICEFROM'             => 'from',
    'D3_EXTSEARCH_EXT_PRICETO'               => 'to',
    'D3_EXTSEARCH_EXT_SIMILAR'               => '(similar)',
    'D3_EXTSEARCH_EXT_CATHIT'                => '(hit from category)',
    'D3_EXTSEARCH_EXT_CMSHEADLINE'           => 'informations',
    'D3_EXTSEARCH_EXT_NOARTDESELECT'         => 'For this site, filters have been set which do not lead to any result. '.
        'Reset the filter to see all articles on this page.',

    'D3_EXTSEARCH_IAS_SEARCH'                => 'search',
    'D3_EXTSEARCH_IAS_STARTSEARCH'           => 'search',

    'D3_EXTSEARCH_RSS_ATTRIBS'               => '| %1$s: %2$s',
    'D3_EXTSEARCH_RSS_INDEXFILTER'           => '| Index: %1$s',
    'D3_EXTSEARCH_RSS_PRICEFILTER'           => '| Price: %1$s',

    'D3_EXTSEARCH_ORDER_BYPRIO'              => 'relevance',
    'WIDGET_LOCATOR_SORT_D3PRIORITY'         => 'relevance',
    'D3PRIORITY'                             => 'relevance',

    'D3_EXTSEARCH_SEARCHINPROGRESS'          => 'search will performed',

    'D3_CUSTOMFIELDTEXT_LIKETITLE'           => 'Term included in title',
    'D3_CUSTOMFIELDTEXT_ISARTNUM'            => 'Term is equal to item number',
    'D3_CUSTOMFIELDTEXT_ISBETWEENSTOCK'      => 'Selection is within the stock',
    'D3_CUSTOMFIELDTEXT_CHOOSESTOCK'         => 'Please select stock',
    'D3_CUSTOMFIELDTEXT_ISBETWEENPRICE'      => 'Selection is within the price',
    'D3_CUSTOMFIELDTEXT_CHOOSEPRICE'         => 'Please select stock',

    'D3_EXTSEARCH_DEBUG_UNABLE_QUERY'        => 'unable to generate query because of chosen settings',
    'D3_EXTSEARCH_DEBUG_UNABLE_DIRECTSHOW'   => 'switch to details page avoided in debug mode:',
);

==> 6.5.0.056.zip: extsearch/src/Application/translations/en/d3_extsearch_lang.php <==
<?php

/**
 * This Software is the property of Data Development and is protected
 * by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * http://www.shopmodule.com
 *
 * @copyright (C) D3 Data Development (Inh. Thomas Dartsch)
 * @author    D3 Data Development - Daniel Seifert <support@shopmodule.com>
 * @link      http://www.oxidmodule.com
 */

$sLangName = "English";

// -------------------------------
// RESOURCE IDENTITFIER = STRING
// -------------------------------
$aLang = array(

//Navigation
    'charset'                                => 'UTF-8',

    'D3_EXTSEARCH_FIELD_NOTICE'              => 'search item',

    'D3_EXTSEARCH_QUICK_HITS'                => 'Hits for',
    'D3_EXTSEARCH_QUICK_SIMILARHITS'         => 'similar hits for',
    'D3_EXTSEARCH_QUICK_MULTIPLEHITS'        => 'suggestions',
    'D3_EXTSEARCH_QUICK_TOBASKET'            => 'add to shopping cart',
    'D3_EXTSEARCH_QUICK_SEARCH'              => 'Searching...',
    'D3_EXTSEARCH_QUICK_NOHIT'               => 'No articles found.',
    'D3_EXTSEARCH_QUICK_TOMUCHHITS'          => 'There are to much hits for this view. <br>Please click here for list view.',
    'D3_EXTSEARCH_QUICK_STARTSEARCH'         => 'start further search...',
    'D3_EXTSEARCH_QUICK_ARTICLE'             => 'article',
    'D3_EXTSEARCH_QUICK_CATEGORY'            => 'category',
    'D3_EXTSEARCH_QUICK_MANUFACTURER'        => 'brand',
    'D3_EXTSEARCH_QUICK_VENDOR'              => 'vendor',
    'D3_EXTSEARCH_QUICK_CONTENT'             => 'information',
    'D3_EXTSEARCH_QUICK_CLOSE'               => 'window close',

    'D3_EXTSEARCH_EXT_NOARTMSG'              => 'To this term were only found a few articles.  We show you similar articles. ',
    'D3_EXTSEARCH_EXT_LESSARTMSG'            => 'To this term were only found a few articles. We added some similar articles to the list.',
    'D3_EXTSEARCH_EXT_PLUGINHEADLINE'        => 'search faster, find faster',
    'D3_EXTSEARCH_EXT_PLUGINBROWSERERROR'    => 'This search extension works in Mozilla Firefox from version 2.0 on and Microsoft Internet Explorer from version 7 on.',
    'D3_EXTSEARCH_EXT_PLUGININSTALLMSG'      => 'Install our free search extension. This will add our shop to the search function of your browser (top right). So you will find what you are looking for anytime and anywhere.<br>(available in Mozilla Firefox from version 2 and Microsoft Internet Explorer from version 7)',
    'D3_EXTSEARCH_EXT_PLUGININSTALLBTN'      => 'install plugin for advanced search',

    'D3_EXTSEARCH_EXT_SEARCHBOX'             => 'filters',
    'D3_EXTSEARCH_EXT_CHOOSECAT'             => 'choose a category',
    'D3_EXTSEARCH_EXT_HITSINCAT'             => 'hits in',
    'D3_EXTSEARCH_EXT_THISCAT'               => 'these categories:',
    'D3_EXTSEARCH_EXT_ALLCATHITS'            => 'show hits for all categories',
    'D3_EXTSEARCH_EXT_CATEGORIES'            => 'Categories:',
    'D3_EXTSEARCH_EXT_SEARCHINCATEGORIES'    => 'search in all categories',
    'D3_EXTSEARCH_EXT_HITSINVENDOR'          => 'hits for',
    'D3_EXTSEARCH_EXT_THISVENDORS'           => 'associated vendors:',
    'D3_EXTSEARCH_EXT_VENDORS'               => 'Vendors:',
    'D3_EXTSEARCH_EXT_SEARCHINVENDORS'       => 'search in all vendors',
    'D3_EXTSEARCH_EXT_ALLVENDORHITS'         => 'show all vendor hits',
    'D3_EXTSEARCH_EXT_CHOOSEVENDOR'          => 'choose a vendor',
    'D3_EXTSEARCH_EXT_HITSINMANUFACTURER'    => 'hits for',
    'D3_EXTSEARCH_EXT_THISMANUFACTURERS'     => 'associated brand:',
    'D3_EXTSEARCH_EXT_MANUFACTURERS'         => 'Brand:',
    'D3_EXTSEARCH_EXT_SEARCHINMANUFACTURERS' => 'search in all brands',
    'D3_EXTSEARCH_EXT_ALLMANUFACTURERHITS'   => 'show all brand hits',
    'D3_EXTSEARCH_EXT_CHOOSEMANUFACTURER'    => 'choose a brand',
    'D3_EXTSEARCH_EXT_HITSATTRIBS'           => 'associated specifications',
    'D3_EXTSEARCH_EXT_ATTRIBSNOSELECTION1'   => 'choose',
    'D3_EXTSEARCH_EXT_ATTRIBSNOSELECTION2'   => '',
    'D3_EXTSEARCH_EXT_ATTRIBSDESELECT1'      => 'deselect',
    'D3_EXTSEARCH_EXT_ATTRIBSDESELECT2'      => '',
    'D3_EXTSEARCH_EXT_ATTRIB_NOASSIGN'       => 'not to "%s" assigned articles',
    'D3_EXTSEARCH_EXT_MULTIPLESELECT'        => 'select multiple "%s"',
    'D3_EXTSEARCH_EXT_ASSIGNFILTER'          => 'assign filter',
    'D3_EXTSEARCH_EXT_UNASSIGNFILTER'        => 'deselect',
    'D3_EXTSEARCH_EXT_CLEARFILTER'           => 'clear all filters',
    'D3_EXTSEARCH_EXT_START_SEARCH'          => 'start search',
    'D3_EXTSEARCH_EXT_ALL'                   => 'all',
    'D3_EXTSEARCH_EXT_CHOOSEPRICE'           => 'choose a price range',
    'D3_EXTSEARCH_EXT_DESELECTPRICE'         => 'show all price ranges',
    'D3_EXTSEARCH_EXT_PRICECATS'             => 'price range',
    'D3_EXTSEARCH_EXT_PRICEFROM'             => 'from',
    'D3_EXTSEARCH_EXT_PRICETO'               => 'to',
    'D3_EXTSEARCH_EXT_SIMILAR'               => '(similar)',
    'D3_EXTSEARCH_EXT_CATHIT'                => '(hit from category)',
    'D3_EXTSEARCH_EXT_CMSHEADLINE'           => 'informations',
    'D3_EXTSEARCH_EXT_NOARTDESELECT'         => 'For this site, filters have been set which do not lead to any result. '.
        'Reset the filter to see all articles on this page.',

    'D3_EXTSEARCH_IAS_SEARCH'                => 'search',
    'D3_EXTSEARCH_IAS_STARTSEARCH'           => 'search',

    'D3_EXTSEARCH_RSS_ATTRIBS'               => '| %1$s: %2$s',
    'D3_EXTSEARCH_RSS_INDEXFILTER'           => '| Index: %1$s',
    'D3_EXTSEARCH_RSS_PRICEFILTER'           => '| Price: %1$s',

    'D3_EXTSEARCH_ORDER_BYPRIO'              => 'relevance',
    'WIDGET_LOCATOR_SORT_D3PRIORITY'         => 'relevance',
    'D3PRIORITY'                             => 'relevance',

    'D3_EXTSEARCH_SEARCHINPROGRESS'          => 'search will performed',

    'D3_CUSTOMFIELDTEXT_LIKETITLE'           => 'Term included in title',
    'D3_CUSTOMFIELDTEXT_ISARTNUM'            => 'Term is equal to item number',
    'D3_CUSTOMFIELDTEXT_ISBETWEENSTOCK'      => 'Selection is within the stock',
    'D3_CUSTOMFIELDTEXT_CHOOSESTOCK'         => 'Please select stock',
    'D3_CUSTOMFIELDTEXT_ISBETWEENPRICE'      => 'Selection is within the price',
    'D3_CUSTOMFIELDTEXT_CHOOSEPRICE'         => 'Please select stock',

    'D3_EXTSEARCH_DEBUG_UNABLE_QUERY'        => 'unable to generate query because of chosen settings',
    'D3_EXTSEARCH_DEBUG_UNABLE_DIRECTSHOW'   => 'switch to details page avoided in debug mode:',
);
